About Isomer
============

The Hackerfleet Operating System (Short Isomer) is being developed specifically to
target a handful of properties and challenges, that are unique to the projected use of the system:

* Locally offline and undisruptable operation (True Internet!)
* Extremely low energy profile
* Must work on embedded systems with low memory, storage and computing capacity
* Realtime handling and federation of incoming and outgoing data
* Many, many different bus and sensor systems as well as configurations
* Clients should not be limited in any way

To master all these challenges, a rather radical approach was chosen after evaluation
of most of the currently available frameworks and libraries.